1;
__END__

=pod

=encoding Shift_JIS

=head1 ソフトウェア名称

SjisTk-JA - Tk modules on Microsoft Windows with Sjis software (Japanese document)

=head1 概要

   use Sjis 0.64;
   use Tk;

=head1 要約

このソフトウェアは Microsoft Windows と Sjis ソフトウェアの組合せて使用
する Tk モジュールです。

JPerl で記述した Perl/Tk アプリケーションを Perl5.8 またはそれ以降に移植
するときに役立ちます。

=head1 ソフトウェアの一覧

   SjisTk::Button.pm
   SjisTk::Canvas.pm
   SjisTk::Checkbutton.pm
   SjisTk::ColorEditor.pm
   SjisTk::Dialog.pm
   SjisTk::DialogBox.pm
   SjisTk::Entry.pm
   SjisTk::Frame.pm
   SjisTk::Label.pm
   SjisTk::LabFrame.pm
   SjisTk::Listbox.pm
   SjisTk::MainWindow.pm
   SjisTk::Menu.pm
   SjisTk::Message.pm
   SjisTk::Radiobutton.pm
   SjisTk::ROText.pm
   SjisTk::Scale.pm
   SjisTk::Table.pm
   SjisTk::Text.pm
   SjisTk::Toplevel.pm

=head1 バグと制限事項

バグ報告、パッチを歓迎します。

=head1 作者

このプロジェクトは 稲葉 準 ina@cpan.org によって始まりました。

=head1 著作権

このソフトウェアはフリーソフトウェアです。あなたは Perl と同じライセンス
の元で再配布及び変更を行うことが出来ます。詳しくは perlartistic を参照して
ください。

このソフトウェアは有用であることを願って頒布されますが、*全くの無保証* 
です。商業可能性の保証や特定の目的への適合性は、言外に示されたものも含
め全く存在しません。

=head1 参考文献

 プログラミングPerl 改訂版
 By Larry Wall, Tom Christiansen, Randal L. Schwartz, 近藤 嘉雪 訳
 1997年12月 発行
 759ページ
 ISBN 4-900900-48-6
 http://www.oreilly.co.jp/out/pperl/index.htm

 プログラミングPerl 第3版 VOLUME 1
 By Larry Wall, Tom Christiansen, Jon Orwant, 近藤 嘉雪 訳
 2002年09月 発行
 756ページ
 ISBN 4-87311-096-3
 http://www.oreilly.co.jp/books/4873110963/

 プログラミングPerl 第3版 VOLUME 2
 By Larry Wall, Tom Christiansen, Jon Orwant, 近藤 嘉雪 訳
 2002年09月 発行
 680ページ
 ISBN 4-87311-097-1
 http://www.oreilly.co.jp/books/4873110971/

 Perlクイックリファレンス
 By Stephen Spainhour, Ellen Siever, Nathan Patwardhan, 近藤 嘉雪, 台場 圭一 監訳
 2000年03月 発行
 784ページ
 ISBN 4-900900-72-9
 http://www.oreilly.co.jp/books/4900900729/

 入門Perl/Tk
 By Nancy Walsh 著、石曽根 信, 西中 芳幸 訳
 1999年12月 発行
 440ページ
 ISBN 4-87311-008-4
 http://www.oreilly.co.jp/books/4873110084/

=head1 謝辞

このソフトウェアは、以下の方々の作成したソフトウェアおよび文書のおかげにより作成
されました。全ての方に感謝いたします。

 Larry Wall, Perl
 http://www.perl.org/

 Nick Ing-Simmons, Tk
 http://search.cpan.org/~ni-s/Tk-804.027/

 Slaven Rezic, Tk
 http://search.cpan.org/~srezic/Tk-804.028_503/

 ハードなソフトの話さん, Perl/Tkで日本語のフォルダ名を使う(Win32)
 http://hardsoft.at.webry.info/200802/article_5.html

 しるひとおらず 2.0 さん, Windows上でPerl/Tkのメニューバーを日本語化する方法(1部未解決) 
 http://home.hiroshima-u.ac.jp/m072848/blog/blosxom.cgi/perl/tk/japanese/menu.htm

 小飼 弾さん, Encode モジュール
 http://search.cpan.org/dist/Encode/

=cut
