use Sjis 0.64;
use Tk;
use Tk::Dialog;
@font = ('-font' => ['ＭＳ　Ｐゴシック', 12, 'normal']);

$mw = MainWindow->new;
$mw->Dialog(
    @font,
    '-title'          => 'test',
    '-text'           => 'ソ',
    '-buttons'        => ['Yes', 'No'],
    '-default_button' => 'No',
)->Show;
MainLoop;
