use Sjis 0.64;
use Tk;
use Tk::DialogBox;

$mw = MainWindow->new;
$mw->DialogBox(
    '-title'          => 'ƒ\',
    '-buttons'        => ['•\', 'ƒ\'],
    '-default_button' => '•\',
    '-cancel_button'  => 'ƒ\',
)->Show;
MainLoop;
