use Sjis 0.64;
use Tk;
@font = ('-font' => ['ＭＳ　Ｐゴシック', 12, 'normal']);

$mw = MainWindow->new;
$mw->Button(
    @font,
    '-text'    => 'ソ',
    '-command' => sub {},
)->pack;
$textvariable = '表';
$mw->Button(
    @font,
    '-textvariable' => \$textvariable,
    '-command'      => sub {},
)->pack;
MainLoop;
